# Partial QR Code Decoder

An aggressive QR code decoder that can recover data from partially missing or damaged QR codes.

## Usage

```bash
partial-qr --input path/to/qr_code_matrix.txt
```

If the input is too corrupted, bruteforce strength can be increased, but beware of the exponential
runtime increase, especially for higher versions:

```bash
partial-qr --input path/to/qr_code_matrix.txt --max-brute-bits 24
```

Additional hints can be provided to the bruteforce to speed it up:

`--ascii` - Assume the data is ASCII, which reduces the search space significantly.

`--url` - Assume the data is a URL, so it must start with either `http://` or `https://`.

`--parallel` - Enable parallel bruteforce using all available CPU cores.
